summaryrefslogtreecommitdiff
path: root/src/mongo/dbtests
diff options
context:
space:
mode:
authorMoustafa Maher Khalil <m.maher@mongodb.com>2023-04-26 19:41:50 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-04-26 21:06:53 +0000
commit269961220e0a5b954a2e0d878c82bd58068030ae (patch)
tree339f5498a26af40fa213d61d38505b1fbadba7cc /src/mongo/dbtests
parent518f3df1276fa9c396b1384554e69dd96e633b6c (diff)
downloadmongo-269961220e0a5b954a2e0d878c82bd58068030ae.tar.gz
SERVER-54150 Recovery from a stable checkpoint should fassert on oplog application failures
Diffstat (limited to 'src/mongo/dbtests')
-rw-r--r--src/mongo/dbtests/repltests.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/dbtests/repltests.cpp b/src/mongo/dbtests/repltests.cpp
index 11680dc1997..c05af813d64 100644
--- a/src/mongo/dbtests/repltests.cpp
+++ b/src/mongo/dbtests/repltests.cpp
@@ -392,12 +392,12 @@ protected:
virtual void reset() const = 0;
};
// Some operations are only idempotent when in RECOVERING, not in SECONDARY. This includes
// duplicate inserts and deletes.
class Recovering : public Base {
protected:
virtual OplogApplication::Mode getOplogApplicationMode() {
- return OplogApplication::Mode::kRecovering;
+ return OplogApplication::Mode::kUnstableRecovering;
}
};
@@ -392,12 +392,12 @@ protected:
virtual void reset() const = 0;
};
-// Some operations are only idempotent when in RECOVERING, not in SECONDARY. This includes
-// duplicate inserts and deletes.
+// Some operations are only idempotent when in RECOVERING from unstable checkpoint, not in
+// SECONDARY. This includes duplicate inserts and deletes.
class Recovering : public Base {
protected: